# -*- coding: utf-8 -*-
"""
Overview
=======
 Handles the logic associated with the Quickshot client's About window.

Legal
=====
 All code, unless otherwise indicated, is original, and subject to the terms of
 the attached licensing agreement.
 
 Copyright (c) 2010
  Neil Tallim <flan@uguu.ca>
  Luke Jennings <ubuntujenkins@googlemail.com>
 
 Quickshot is free software: you can redistribute it and/or modify it 
 under the terms of the GNU General Public License version 3, as published 
 by the Free Software Foundation.
 
 Quickshot is distributed in the hope that it will be useful, but 
 WITHOUT ANY WARRANTY; without even the implied warranties of 
 MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along 
 with Quickshot.  If not, see <http://www.gnu.org/licenses/>.
"""
import logging

import gtk

import quickshot.common

import credits
import licence

logger = logging.getLogger('quickshot.gui.about')

_ABOUT_WINDOW = None #: Simple singleton-like reference-variable.

def AboutWindow(parent):
    """
    Sets up and shows the about-window.

    @type parent: gtk.Window
    @param parent: The window to use as a parent.

    @rtype: gtk.Window
    @return: The about-window.
    """
    global _ABOUT_WINDOW
    if not _ABOUT_WINDOW:
        logger.debug("Loading about")
        
        builder = gtk.Builder()
        builder.add_from_file(quickshot.common.get_data_file('ui', 'about.ui'))

        about_window = builder.get_object('win_about')
        about_window.set_transient_for(parent)
        
        btn_close = builder.get_object('btn_close')
        btn_close.connect("clicked", _close_about)

        btn_credits = builder.get_object('btn_credits')
        btn_credits.connect("clicked", _show_credits)
        
        btn_licence = builder.get_object('btn_licence')
        btn_licence.connect("clicked", _show_licence)

        _ABOUT_WINDOW = about_window
    _ABOUT_WINDOW.show()
    return _ABOUT_WINDOW
    
def _close_about(*args):
    """
    Disposes of the about-window.

    @type *args: arg*
    @param *args: Not used.
    """
    global _ABOUT_WINDOW
    logger.debug("Closing about")
    _ABOUT_WINDOW.destroy()
    _ABOUT_WINDOW = None
    
def _show_credits(*args):
    """
    Displays the credits-window.

    @type *args: arg*
    @param *args: Not used.
    """
    credits.CreditsWindow(_ABOUT_WINDOW)

def _show_licence(*args):
    """
    Displays the licence-window.

    @type *args: arg*
    @param *args: Not used.
    """
    licence.LicenceWindow(_ABOUT_WINDOW)
    
