# -*- coding: utf-8 -*-
"""
Overview
=======
 Handles the logic associated with the Quickshot client's Credits window.

Legal
=====
 All code, unless otherwise indicated, is original, and subject to the terms of
 the attached licensing agreement.
 
 Copyright (c) 2010
  Neil Tallim <flan@uguu.ca>
  Luke Jennings <ubuntujenkins@googlemail.com>
 
 Quickshot is free software: you can redistribute it and/or modify it 
 under the terms of the GNU General Public License version 3, as published 
 by the Free Software Foundation.
 
 Quickshot is distributed in the hope that it will be useful, but 
 WITHOUT ANY WARRANTY; without even the implied warranties of 
 MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along 
 with Quickshot.  If not, see <http://www.gnu.org/licenses/>.
"""
import logging

import quickshot.common

import gtk

logger = logging.getLogger('quickshot.gui.credits')

_CREDITS_WINDOW = None #: Simple singleton-like reference-variable.

def CreditsWindow(parent):
    """
    Sets up and shows the credits-window.

    @type parent: gtk.Window
    @param parent: The window to use as a parent.

    @rtype: gtk.Window
    @return: The credits-window.
    """
    global _CREDITS_WINDOW
    if not _CREDITS_WINDOW:
        logger.debug("Loading credits")
        
        builder = gtk.Builder()
        builder.add_from_file(quickshot.common.get_data_file('ui', 'credits.ui'))

        credits_window = builder.get_object('win_credits')
        credits_window.set_transient_for(parent)
        
        btn_close = builder.get_object('btn_close')
        btn_close.connect("clicked", _close_credits)

        _CREDITS_WINDOW = credits_window
    _CREDITS_WINDOW.show()
    return _CREDITS_WINDOW
    
def _close_credits(*args):
    """
    Disposes of the credits-window.

    @type *args: arg*
    @param *args: Not used.
    """
    global _CREDITS_WINDOW
    logger.debug("Closing credits")
    _CREDITS_WINDOW.destroy()
    _CREDITS_WINDOW = None
    
