# -*- coding: utf-8 -*-
"""
Overview
=======
 Determines properties of the execution environment.

Legal
=====
 All code, unless otherwise indicated, is original, and subject to the terms of
 the attached licensing agreement.
 
 Copyright (c) 2010
  Neil Tallim <flan@uguu.ca>
 
 Quickshot is free software: you can redistribute it and/or modify it 
 under the terms of the GNU General Public License version 3, as published 
 by the Free Software Foundation.
 
 Quickshot is distributed in the hope that it will be useful, but 
 WITHOUT ANY WARRANTY; without even the implied warranties of 
 MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along 
 with Quickshot.  If not, see <http://www.gnu.org/licenses/>.
"""
import os
import subprocess

def _detect_desktop_environment():
    """
    Identify the working WM.
    
    @rtype: basestring
    @return: The name of the current desktop environment.
    """
    if os.environ.get('KDE_FULL_SESSION') == 'true':
        return 'kde'
    elif os.environ.get('DESKTOP_SESSION') == 'gnome':
        return 'gnome'   
    else:
        try:
            popen = subprocess.Popen(('xprop', '-root', '_DT_SAVE_MODE'), stdout=subprocess.PIPE)
            if popen.wait() == 0:
                if ' = "xfce4"' in popen.stdout.read():
                    return 'xfce4'
        except Exception, e:
            pass
    return 'generic'

def get_elevate_privilages_command():
    """
    Determines the appropriate sudo command to issue for the user's
    environment.
    
    @rtype: basestring
    @return: The sudo command to issue.

    @raise NoCommandError: The appropriate sudo command could not be
        determined.
    """
    environment = _detect_desktop_environment()
    
    if environment in ('gnome', 'xfce4'):
        return 'gksudo'
    elif environment == 'kde':
        return 'kdesu'
    else: #Pick whatever's available.
        if not subprocess.call(('which', 'gksudo')):
            return 'gksudo'
        elif not subprocess.call(('which', 'kdesu')):
            return 'kdesu'
    raise NoCommandError("No suitable sudo-analogue command could be found")
    
def get_logout_command():
    """
    Determines the appropriate logout command to issue for the user's
    environment.
    
    @rtype: tuple
    @return: The parameterised logout command to issue.

    @raise NoCommandError: The appropriate logout command could not be
        determined.
    """
    environment = _detect_desktop_environment()
    
    if environment == 'gnome':
        return ('gnome-session-save', '--logout',)
    elif environment == 'kde':
        return (
         'dbus-send', '--session', '--dest=org.kde.ksmserver',
         '/KSMServer', 'org.kde.KSMServerInterface.saveCurrentSession', '&&', 'qdbus org.kde.ksmserver',
         '/KSMServer', 'logout', '0', '0', '0',
        )
    elif desktop == 'xfce':
        return ('xfce4-session-logout', '--logout',)
    raise NoCommandError("No suitable logout command could be found")
    
class Error(Exception):
    """
    The base class from which all exceptions native to this module inherit.
    """
    pass

class NoCommandError(Error):
    """
    Signifies that the no appropriate command could be found for the desired
    action.
    """
    pass
    
